@@ -1,6 +1,7 @@
 from dataclasses import asdict
 from datetime import datetime
 from typing import Optional
+import pytz
 
 from requests import Response
 
@@ -56,10 +57,10 @@ class DeviceMonitoring(ApiEndpoint):
     @api_call(MonitoringDataResponse)
     def get_data_batch(self,
                        device_id: str,
-                       lwm2m_url: Optional[str],
-                       alias: Optional[str],
-                       start_time: datetime,
-                       end_time: Optional[datetime],
+                       lwm2m_url: Optional[str] = None,
+                       alias: Optional[str] = None,
+                       start_time: Optional[datetime] = None,
+                       end_time: Optional[datetime] = None,
                        limit=2048
                        ) -> Response:
         if lwm2m_url is not None:
@@ -70,7 +71,9 @@ class DeviceMonitoring(ApiEndpoint):
             url = self.get_url(f"/data/{device_id}/alias/{safe_alias}")
         else:
             raise ValueError("You must specify either LwM2M URL or alias of the resource")
-        params = {"timeRangeStart": start_time.strftime(ISO_INSTANT_FORMAT), "limit": limit}
+        if start_time is None:
+            raise ValueError("You must specify at least the start time for the query")
+        params = {"timeRangeStart": start_time.astimezone(pytz.utc).strftime(ISO_INSTANT_FORMAT), "limit": limit}
         if end_time:
-            params["timeRangeEnd"] = end_time.strftime(ISO_INSTANT_FORMAT)
+            params["timeRangeEnd"] = end_time.astimezone(pytz.utc).strftime(ISO_INSTANT_FORMAT)
         return self.session.get(url, params=params)
